<?php

/**
 * @file
 * Configuration options for the module.
 */

/**
 * Administration form.
 */
function conditional_message_client_config_form($form, &$form_state) {

  // Warning about conditional_message server/client enabled simultaneously.
  if (module_exists('conditional_message')) {
    drupal_set_message('"Conditional message client" takes precedence over
    "conditional message" module. Please disable one of the modules for
    consistency.', 'warning');
  }

  $form['conditional_message'] = array(
    '#title' => t('Conditional message client configurations'),
    '#type' => 'fieldset',
  );

  // Display in columns.
  drupal_add_css('.conditional-message-options-columns {column-count:2;column-gap:10px;}', 'inline');

  $form['conditional_message']['multisite_setup'] = array(
    '#title' => t('Client site setup'),
    '#type' => 'fieldset',
  );

  $server_site = variable_get('conditional_message_server_site', 'https://example.com');
  $form['conditional_message']['multisite_setup']['conditional_message_server_site'] = array(
    '#type' => 'textfield',
    '#title' => t('Server site'),
    '#description' => t('Enter the URL of the site that will provide the configurations (https://example.com).'),
    '#default_value' => $server_site,
    '#size' => 60,
    '#maxlength' => 255,
    '#required' => FALSE,
  );

  $form['#validate'][] = 'conditional_message_client_config_form_validate';

  return system_settings_form($form);
}

/**
 * Validation of the conditional message client configuration form.
 */
function conditional_message_client_config_form_validate($form, &$form_state) {
  $server_url = $form_state['values']['conditional_message_server_site'];
  if (empty($server_url)) {
    drupal_set_message(t('There is no server site selected. This option is required.'), 'warning');
  }
  else {
    $end = substr($server_url, -1, 1);
    if ($end == '/') {
      $form_state['values']['conditional_message_server_site'] = substr($server_url, 0, -1);
    }
  }
}
